#
# spec file for package totem
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           totem
Version:        43.1
Release:        1.3
Summary:        Movie Player for the GNOME Desktop
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Multimedia/Video/Players
URL:            https://wiki.gnome.org/Apps/Videos
Source0:        https://download.gnome.org/sources/totem/43/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM d16d9ad1d2b214996639e4f01c4515b611fb2739.patch -- data: Add new canonical mime-type for AVI files
Patch1:         https://gitlab.gnome.org/GNOME/totem/-/commit/d16d9ad1d2b214996639e4f01c4515b611fb2739.patch

BuildRequires:  appstream-glib
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gstreamer-plugins-good
BuildRequires:  gstreamer-plugins-good-gtk
# For gst-inspect tool
BuildRequires:  gstreamer-utils >= 0.11.93
BuildRequires:  gtk-doc
BuildRequires:  meson >= 0.50.0
BuildRequires:  pkgconfig
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(cairo) >= 1.14.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.56.0
BuildRequires:  pkgconfig(gnome-desktop-3.0)
BuildRequires:  pkgconfig(grilo-0.3) >= 0.3.0
BuildRequires:  pkgconfig(gsettings-desktop-schemas)
BuildRequires:  pkgconfig(gstreamer-1.0) >= 1.6.0
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0)
BuildRequires:  pkgconfig(gstreamer-tag-1.0)
BuildRequires:  pkgconfig(gstreamer-video-1.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(iso-codes)
BuildRequires:  pkgconfig(libhandy-1)
BuildRequires:  pkgconfig(libpeas-1.0) >= 1.1.0
BuildRequires:  pkgconfig(libpeas-gtk-1.0)
BuildRequires:  pkgconfig(libportal-gtk3)
BuildRequires:  pkgconfig(libxml-2.0) >= 2.6.0
BuildRequires:  pkgconfig(pygobject-3.0) >= 2.90.3
BuildRequires:  pkgconfig(shared-mime-info)
BuildRequires:  pkgconfig(totem-plparser) >= 3.26.5
BuildRequires:  pkgconfig(x11)

# Set a hard requires on the new thumbnailer sub-package
Requires:       totem-video-thumbnailer

# We want a useful set of plugins
Requires:       gstreamer-plugins-base
Requires:       gstreamer-plugins-good
Requires:       gstreamer-plugins-good-gtk
Requires:       iso-codes
Recommends:     gstreamer-plugins-bad
Recommends:     gstreamer-plugins-ugly
Recommends:     totem-plugins

# totem-plugin-brasero has been removed.
Obsoletes:      totem-plugin-brasero < 3.38.0
# totem-plugin-upnp has been substituted by a grilo plugin.
Obsoletes:      totem-plugin-upnp < 3.38.0
# The browser plugins were dropped with totem 3.13.90
Obsoletes:      nautilus-totem < 3.31.92
Obsoletes:      totem-browser-plugin < 3.13.90
Obsoletes:      totem-browser-plugin-gmp < 3.13.90
Obsoletes:      totem-browser-plugin-vegas < 3.13.90
%glib2_gsettings_schema_requires
Obsoletes:      totem-plugin-zeitgeist < 3.38.0

%description
Totem is a movie player for the GNOME desktop based on GStreamer. It
features a playlist, a full-screen mode, seek and volume controls, and
complete keyboard navigation.

%package plugins
Summary:        Plugins for Totem Movie Player
Group:          Productivity/Multimedia/Video/Players
Requires:       %{name} = %{version}
# Gromit Annotation plugin
Suggests:       gromit
%glib2_gsettings_schema_requires

%description plugins
Totem is a movie player for the GNOME desktop based on GStreamer.

This package includes plugins for Totem, to add advanced features.

%package devel
Summary:        Developer Documentation for Totem Movie Player
Group:          Development/Libraries/GNOME
Requires:       %{name} = %{version}

%description devel
Totem is a movie player for the GNOME desktop based on GStreamer.

This package contains developer documentation.

%package video-thumbnailer
Summary:        Totem video thumbnailer
Supplements:    (gnome-shell and nautilus)
Provides:       totem:%{_bindir}/totem-video-thumbnailer

%description video-thumbnailer
Totem is a movie player for the GNOME desktop based on GStreamer.

This package contains the video thumbnailer.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-D enable-easy-codec-installation=yes \
	-D enable-gtk-doc=true \
	-D enable-python=yes \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_prefix}

%ldconfig_scriptlets

%check
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/org.gnome.Totem.appdata.xml
desktop-file-validate %{buildroot}%{_datadir}/applications/org.gnome.Totem.desktop

%files
%license COPYING
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/%{name}
%{_datadir}/GConf/gsettings/totem.convert
%{_datadir}/dbus-1/services/org.gnome.Totem.service
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/org.gnome.Totem.appdata.xml
%{_datadir}/applications/*.desktop
%{_datadir}/glib-2.0/schemas/org.gnome.totem.enums.xml
%{_datadir}/glib-2.0/schemas/org.gnome.totem.gschema.xml
%{_datadir}/icons/hicolor/*/apps/*.svg
%{_libexecdir}/totem-gallery-thumbnailer
%{_mandir}/man1/%{name}.1%{ext_man}
# Own directories for plugins
%dir %{_libdir}/totem
%dir %{_libdir}/totem/plugins
%{_libdir}/libtotem.so.0*
%{_libdir}/girepository-1.0/Totem-1.0.typelib

%files lang -f %{name}.lang

%files plugins
# Explicitly list plugins
%{_libdir}/totem/plugins/apple-trailers/
%{_libdir}/totem/plugins/autoload-subtitles/
%{_libdir}/totem/plugins/im-status/
%{_libdir}/totem/plugins/mpris/
%{_libdir}/totem/plugins/open-directory/
%{_libdir}/totem/plugins/opensubtitles/
%{_libdir}/totem/plugins/properties/
%{_libdir}/totem/plugins/pythonconsole/
%{_libdir}/totem/plugins/recent/
%{_libdir}/totem/plugins/rotation/
%{_libdir}/totem/plugins/save-file/
%{_libdir}/totem/plugins/screensaver/
%{_libdir}/totem/plugins/screenshot/
%{_libdir}/totem/plugins/skipto/
%{_libdir}/totem/plugins/vimeo/
%{_libdir}/totem/plugins/variable-rate/
%{_datadir}/GConf/gsettings/opensubtitles.convert
%{_datadir}/GConf/gsettings/pythonconsole.convert
%{_datadir}/glib-2.0/schemas/org.gnome.totem.plugins.opensubtitles.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.totem.plugins.pythonconsole.gschema.xml

%files devel
%doc AUTHORS NEWS README
%{_datadir}/gtk-doc/html/totem/
%{_includedir}/totem/
%{_libdir}/libtotem.so
%{_libdir}/pkgconfig/totem.pc
%{_datadir}/gir-1.0/*.gir

%files video-thumbnailer
%{_bindir}/totem-video-thumbnailer
%{_mandir}/man1/totem-video-thumbnailer.1%{ext_man}
%dir %{_datadir}/thumbnailers
%{_datadir}/thumbnailers/totem.thumbnailer

%changelog
* Tue Oct 22 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.1:
  + Fix scroll-by-page GTK setting breaking slider
  + Fix a number of MPRIS playback controls not working correctly
  + Fix a number of opensubtitles dialogue problems
  + Fix hyphens appearing in filenames
  + Force using newer GStreamer va-api plugins, fixing scrambled
    videos in some cases
  + Fix error showing the keyboard shortcuts
  + Fix assertion when backends send out audio or image files even
    though we asked them to be filtered out
  + Updated translations.
- Drop patch fixed upstream:
  + ac2d02530d3b555e44907162be05536a5927b2a0.patch
* Fri Dec  1 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add upstream bug fix patches:
  + ac2d02530d3b555e44907162be05536a5927b2a0.patch: gst: Force
    using newer GStreamer libva plugins
  + d16d9ad1d2b214996639e4f01c4515b611fb2739.patch: data: Add new
    canonical mime-type for AVI files
* Wed Sep 13 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add totem:%%{_bindir}/totem-video-thumbnailer split-provides to
  the new thumbnailer subpackage: not really needed, as the
  sub-package is a hard-dependency to totem anyway, but that might
  possibly change in the future.
* Wed Aug 23 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Split out new sub-package: totem-video-thumbnailer: put the
  video-thumbnailing functionality into its own package, allowing
  users not wanting totem installed still keep video thumbnailing
  functionality in software like nautilus. Add a Supplements
  (gnome-shell and nautilus) in the sub-package, install
  automatically when both are present. Also set a hard Requires on
  the subpackage in the main totem package.
* Mon Mar 13 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Drop obsolete and unused intltool, vala and
  pkgconfig(libepc-ui-1.0) BuildRequires.
* Fri Sep 16 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + Remove obsolete Bugzilla entries from desktop file.
  + Updated translations.
* Tue Sep  6 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.rc:
  + Fix videos not playing when opening through nautilus 43.
  + Updated translations.
* Fri Aug 19 2022 Ben Greiner <code@bnavigator.de>
- Don't do python code linting for the rpm package
  + Drop build requirement of python3-pylint
  + Checking code lint is a tool for upstream developers and
    irrelevant for the functionality of a binary distribution
    package
* Fri Aug 19 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 43.beta:
  + Throw a better error if OpenGL couldn't init.
  + Translate DVD/VCD device errors.
  + Save screenshots into ~/Pictures/Screenshots.
  + Make search entry keyboard navigable.
  + Add playlist page to GTK inspector (disabled by default).
  + Fix fullscreen header bar not showing up.
- Use upstream published tarballs.
* Wed Jul 27 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.alpha:
  + Update thumbnailing code for gnome-desktop API changes.
  + Fix crashes and warnings when some plugins are missing.
  + Use GResources to load UI files, simplify plugin declarations,
    and remove a lot of unused code.
  + Update man page.
- Add pkgconfig(libportal-gtk3) BuildRequires: New dependency.
* Sat Mar 19 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.0:
  + Updated appdata screenshots.
  + Fix screenshot functionality not working since the port to the
    OpenGL video widget.
  + Updated translations.
* Fri Feb 25 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.beta:
  + Port video widget from obsolete Clutter to OpenGL
  + Move subtitles and audio track selection to its own menu
  + Add shortcuts for mute, cycling through subtitles, toggling
    subtitles and seeking to specific places in the video
  + Implement a enabled-by-default native MPRIS plugin to replace
    the Python MPRIS plugin
  + Remove media-player-keys plugin that supported the old GNOME
    Settings Daemon API, now replaced by MPRIS
  + Show more precise elapsed time when stepping frame-by-frame
  + Implement "search by title" in OpenSubtitles plugin
  + Updated translations.
- Drop patches fixed upstream:
  + totem-fix-meson-061.patch
  + totem-enable-vaapi.patch
- Drop conditional zeitgeist plugin and Obsolete it, removed
  upstream long ago.
- Drop gcc-c++, pkgconfig(clutter-1.0), pkgconfig(clutter-gst-3.0),
  and pkgconfig(clutter-gtk-1.0) BuildRequires following upstreams
  port to OpenGL. Also drop gstreamer-plugin-cluttergst3
  Recommends.
- Add gstreamer-plugins-good-gtk, pkgconfig(libhandy-1) and
  pkgconfig(libpeas-gtk-1.0) BuildRequires: New dependencies. Also
  add gstreamer-plugins-good-gtk Requires.
- Drop the workaround for parallel build breakage, no longer
  needed.
- Switch to gitcheckout via source service.
* Wed Feb  2 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add totem-fix-meson-061.patch: Fix build with meson 0.61 and
  newer.
- Add desktop-file-utils BuildRequires and add a check section,
  manually check metainfo and desktop file, we can not run the full
  meson_test suite during build as it requires a working desktop,
  and not a headless build enviroment.
- Drop unused update-desktop-files BuildRequires.
- Use ldconfig_scriptlets macro for post(un) handling.
* Thu Nov  4 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Stop passing the no longer used nor recognized options
  enable-introspection=yes and enable-vala=yes to meson.
* Tue Oct 12 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.2:
  + Add support for MPL subtitles.
  + Fix OpenUri method in MPRIS plugin.
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Wed Jun 16 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.1:
  + Fix "Undetermined" appearing in language selection menus
  + Make XF86Back go back up a level in library
  + Fix the logo not showing when there's no cover
  + Don't throw error when seeking past the end of an MPEG file
  + Remove application/ogg from the supported mime-types
  + Block more GStreamer plugins that can't be used for
    thumbnailing
  + Remove Flatpak definitions from distribution tarball
  + Updated translations.
* Fri Dec 25 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Add totem-enable-vaapi.patch: Enable vaapi support again.
* Fri Sep 11 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Updated translations.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 3.37.90:
  + Add support for Tracker 3 indexer.
  + Support auto-loading VTT subtitles.
  + Fix some stutters on some systems when current state is being
    saved to disk.
  + Better error messages when SSL/TLS support is missing.
  + Improve the search entry's behaviour.
  + Improve the way time is written in some places.
  + Remove association with audio files, as we really don't want
    to be an audio player.
  + Fix YouTube search not working.
  + Fix a number of keyboard shortcuts not working.
  + Remove a number of deprecated calls.
  + Updated translations.
- Drop totem-Fix-bracket-keys-and-backspace.patch: fixed upstream.
* Thu Jun 18 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Drop totem-revert-vaapi-disable.patch: Changes elsewhere in the
  stack have again broken vaapi support in totem, remove patch at
  least for now.
* Thu Apr 16 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Drop gnome-dvb-daemon Suggests: Pulls in extra packages on the
  dvd that we would like to avoid. The Suggests are so weak that it
  plays no real role anyway, and the users into this will install
  the needed packages manually anyway.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Sat Jan 11 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Add totem-Fix-bracket-keys-and-backspace.patch: variable-rate:
  Fix bracket keys and backspace not working in search entry.
* Fri Oct  4 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + Fix broken symbolic icon.
  + Updated translations.
- Drop totem-fix-symbolic-icon.patch: Fixed upstream.
* Mon Sep 30 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add totem-fix-symbolic-icon.patch: Fix symbolic icon.
* Fri Sep  6 2019 mgorse@suse.com
- Update to version 3.34.0:
  + Make introspection non-optional for the plugin system to work.
  + Updated translations.
* Wed Sep  4 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add totem-revert-vaapi-disable.patch: Revert upstreams disabling
  of vaapi support, it works fine on openSUSE.
* Tue Sep  3 2019 mgorse@suse.com
- Update to version 3.33.90:
  + Update application icon.
  + Use title case for the "Open Containing Folder" menu item.
  + Disable VAAPI support for now, it's too buggy.
  + Changes in version 3.33.0:
  + Add "Open containing folder" menu item.
  + Include "totem" in the desktop keywords.
  + Make --version command-line option public.
  + Reduce GSettings writes on startup.
  + Fix menu sensitivity for OpenSubtitles plugin.
- Add open-directory plugin.
  + Remove obsolete LIRC and Brasero plugins.
- Remove/obsolete -plugin-brasero package: removed upstream.
- Remove comments related to lirc: plugin removed upstream.
* Fri Jul 12 2019 Michael Gorse <mgorse@suse.com>
- Update to version 3.32.1:
  + Show the application window when opening a new file.
  + Work-around "Can't play a text file without video or
    visualizations" error.
  + Build fixes.
  + Updated translations.
- Drop totem-buildfixes.patch and totem-fix-appdata.patch: fixed
  upstream.
* Thu Apr 18 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add upstream bug fix patches:
  + totem-buildfixes.patch.
  + totem-fix-appdata.patch.
* Fri Mar  8 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated translations.
* Tue Mar  5 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.31.92:
  + Add an error message when file is encrypted, or empty, or DVD
    playback is attempted with missing libraries.
  + Make "Stop" keyboard button act like the Stop button on a CD
    player.
  + Remove all mentions of the external chapters plugin, it wasn't
    used since 2012.
  + Fix possible crash when browsing.
  + Fix DesktopEntry in MPRIS plugin.
  + Updated translations.
* Wed Feb 20 2019 bjorn.lie@gmail.com
- Update to version 3.31.91:
  + Move nautilus properties page to nautilus module.
  + Fix fullscreen toolbar's appearance in RTL languages.
  + Update appdata and screenshots.
  + Don't advertise VCD support, GStreamer 1.0 has never supported
    it.
  + Add support for "start time" in playlists.
  + Make Ctrl+W navigate back before exiting.
  + Make it possible to load subtitles from the command-line.
  + Fix media player controls not appearing in gnome-shell in some
    cases, and the next/previous buttons not working.
  + Make previous/next buttons' state update when a movie contains
    chapters.
  + Use better labels for Subtitles and Languages menus.
  + Fix some display problems when files are longer than detected.
  + And other smaller bug fixes:
  - Throw a warning when download buffering breaks because of a
    missing plugin.
  - Make framerate more precise in properties.
  - Fix a warning on exit when brasero is not installed.
- Changes from version 3.31.90:
  + New icon.
  + Remove app menu.
  + Modernise user documentation.
  + Loads of fixes in "Make available offline" functionality.
  + Fix proxy configuration in Flatpak.
  + Disable VA-API plugins in thumbnailer.
  + Plenty of build fixes and changes, including:
  - Use gettext instead of intltool.
  - Fix parallel build.
  - Remove gromit, ontop and zeitgeist plugins.
  - Remove most X11 dependencies (except XInitThreads).
- Drop nautilus sub package.
* Mon Feb  4 2019 Marketa Calabkova <mcalabkova@suse.com>
- Fix req#663737 - build with translation-update-upstream
  version 20181128 (bsc#1087076)
* Tue Dec 11 2018 bjorn.lie@gmail.com
- Update to version 3.30.0:
  + Add frame stepping shortcuts to the keyboard shortcuts list.
  + Fix opensubtitles plugin not working.
  + Fix problems using gallery generation feature in screenshot
    plugin.
  + Make sure not to autostart gnome-screensaver when running in
    non-GNOME.
  + Build fixes.
* Tue Jul 24 2018 bjorn.lie@gmail.com
- Update to version 3.26.2:
  + Fix OpenSubtitles dialogue not opening.
  + Fix error early in build when vala is not available.
* Thu Jun 21 2018 bjorn.lie@gmail.com
- Align with what meson looks for:
  + Drop pkgconfig(gstreamer-plugins-bad-1.0) and
    pkgconfig(gstreamer-plugins-base-1.0) BuildRequires.
  + Add pkgconfig(gstreamer-pbutils-1.0)
    and pkgconfig(gstreamer-video-1.0) BuildRequires.
* Fri Jun 15 2018 bjorn.lie@gmail.com
- Update to version 3.26.1:
  + Fix crash when properties tab is closed too fast.
  + Thumbnail OPUS and M4B audio files.
  + Fix thumbnailing on platforms with V4L M2M hardware decoders.
  + Fix playing back MJPEG files.
  + Fix Python Console menu not appearing.
  + Build fixes:
  - Remove dependency on Debian-specific pycompile utility.
  - Fix build with gtk-doc 1.26.
- Drop upstream fixed/applied patches:
  + totem-remove-pycopile.patch
  + totem-fix-properties-crash.patch
  + totem-add-opus-ogg.patch
  + totem-fix-gtk-doc.patch
  + totem-nb-translations.patch
  + totem-thumbnailer-blacklist-fixes.patch
  + totem-fix-libtotem_gir-dependency.patch
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Mon Mar 12 2018 bjorn.lie@gmail.com
- Add totem-fix-libtotem_gir-dependency.patch: build: Fix
  libtotem_gir dependency for vala plugins.
- Add gstreamer-plugins-ugly Recommends: We want to pull in the
  codecs available in that package (mp3, ac3 and mpeg2 support).
- Drop la files rm from install section, no longer needed, we are
  using meson build system now.
* Mon Mar 12 2018 dimstar@opensuse.org
- Replace gstreamer-plugin-gstclutter-3_0 Requires with
  gstreamer-plugin-cluttergst3 Recommends: the package has been
  renamed and is no longer strictly required.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed Jan 24 2018 tchvatal@suse.com
- Drop python-beautifulsoup and python-httplib2 recommends: BBC
  rewrote the iplayer plugin and as such the recommends do not make
  sense anymore.
* Tue Jan  9 2018 zaitor@opensuse.org
- Add totem-thumbnailer-blacklist-fixes.patch: Fixes to the
  thumbnailer blacklists plugins (bgo#790491).
* Tue Nov 21 2017 luc14n0@linuxmail.org
- Update Url to https://wiki.gnome.org/Apps/Videos: current Totem's
  web page.
* Mon Nov 20 2017 zaitor@opensuse.org
- Add upstream stable branch bug fix commits:
  + totem-remove-pycopile.patch (bgo#787965).
  + totem-fix-properties-crash.patch (bgo#787996).
  + totem-add-opus-ogg.patch (bgo#788440).
  + totem-fix-gtk-doc.patch (bgo#789202).
  + totem-nb-translations.patch.
- Enable gtk-doc BuildRequires again and pass -Denable-gtk-doc=true
  to meson, no longer fails to build.
- No longer Provide and Obsolete totem-devel, we have been building
  this sub-package again for a long time.
- Stop removing SWF and Real mime types.
- No longer pass suse_update_desktop_file macro, no longer needed.
* Fri Sep 15 2017 fcrozat@suse.com
- Build Totem-1.0.gir first as workaround for parallel build being
  fragile (bgo#786248).
* Mon Sep 11 2017 dimstar@opensuse.org
- Update to version 3.26.0:
  + Fix a possible build race.
  + Fix lirc plugin compilation.
  + Python console bug fixes.
  + Install appdata in the new location.
  + Updated translations.
- Drop totem-fix-random-buildfails.patch: fixed upstream.
* Sat Sep  9 2017 jengelh@inai.de
- Invoke ldconfig without running sh for scriptlet.
- Avoid running fdupes over hardlink boundaries.
* Fri Sep  8 2017 zaitor@opensuse.org
- Add totem-fix-random-buildfails.patch: Fix random buildfails in
  buildservice, patch from upstream git.
- Set build_zeitgeist_plugin define to 0, no longer build the
  zeitgeist plugin, as it currently breaks the build with above
  patch.
- Pass enable-easy-codec-installation=yes, enable-nautilus=yes,
  enable-python=yes, enable-vala=yes and enable-introspection=yes
  to meson, ensure we build all the features we want.
* Tue Aug 15 2017 zaitor@opensuse.org
- Temp disable gtk-doc BuildRequires and stop passing
  Denable-gtk-doc=true to meson, as gtk-doc 1.26 gives a buildfail.
* Mon Aug 14 2017 zaitor@opensuse.org
- Update to version 3.25.90.1:
  + Build fixes.
- Drop obsolete post(un) handling:
  + glib2_gsettings_schema_post(un)
  + desktop_database_post(un)
  + icon_theme_cache_post(un)
* Wed Aug  9 2017 zaitor@opensuse.org
- Update to version 3.25.90:
  + Move to meson build system.
  + Fix media-player keys usage to match API documentation.
  + Fix internal video widget API documentation.
  + Remove unused totem-audio-preview.
  + Split off video thumbnailer into thumbnailer and gallery maker.
  + Blacklist bmcdec plugin in the thumbnailer.
- Add meson BuildRequires and switch autotools macros configure,
  make and makeinstall to meson, meson_build and meson_install
  following upstream switch to Meson build system.
- Add gtk-doc and python3-pylint BuildRequires: New dependencies
  needed now that we use meson buildsystem.
- Temp disable lirc-devel BuildRequires and the previously built
  lirc plugin, meson does not recognise the lirc_client.
- Drop totem-media-player-keys-fix-usage-vs-api.patch: Fixed
  upstream.
* Fri May 26 2017 zaitor@opensuse.org
- Add totem-media-player-keys-fix-usage-vs-api.patch:
  media-player-keys: Fix usage to match API documentation
  (bgo#781589).
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Add Flatpak build definition.
  + Updated translations.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 3.23.90:
  + Add keyboard shortcut to de-select all items.
  + Fix possible crash on first run.
  + Set a minimum width for the "Go" menu.
  + Mark many audio and video mime-types as handled.
  + Add more shortcuts to the keyboard shortcuts dialogue.
  + Fix a small memory leak in thumbnailer.
  + Fix missing plugins' startup notification on Wayland.
  + Fix crash when network turns off.
  + Port to non-obsoleted widgets.
  + Build fixes.
* Thu Feb  2 2017 jengelh@inai.de
- Remove ancient %%clean section. Improve summaries.
* Tue Jan 31 2017 zaitor@opensuse.org
- Lower gstreamer-plugins-bad Requires to a Recommends, scaletempo
  have been moved to gstreamer-plugins-good (back in 2012).
- Split out the brasero plugin in own sub package.
- Following this: Highten brasero Recommends to Requires, the full
  app is really needed for this to work properly.
* Sat Sep 17 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Fix symbolic icon not appearing in gnome-shell's top bar.
  + Updated translations.
* Wed Aug 31 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + Add variable rate playback menu.
  + Build fixes.
  + Fix thumbnailing of 4k videos.
- Drop totem-Fix-build-werror.patch: Fixed upstream.
* Wed Apr 13 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Make playback rate available to plugins.
  + Add more shortcuts for the shortcuts help window.
  + Fix a number of compilation warnings.
  + Updated translations.
- Add totem-Fix-build-werror.patch: backend: Fix the build with
  - Werror=format. Fix build on i586 (bgo#765036).
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Fix a theming regression in the play/pause button box.
  + Updated translations.
* Thu Mar 17 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + Fix regression from 3.18 which could cause none of the builtin
    plugins to be activated.
  + Updated translations.
* Fri Mar  4 2016 zaitor@opensuse.org
- Update to version 3.19.91:
  + Change "Skip to" label in shortcuts.
  + Make header popup translucent in fullscreen as per mockups.
  + Fix totem-audio-preview translations.
  + Add context to strings to translate in the shortcut window.
  + Updated translations.
* Sat Dec 19 2015 damjanovic.ivo@gmail.com
- Update to version 3.19.3:
  + Port to grilo 0.3.0.
  + Add a shortcuts help window.
  + Use new grl-video-title-parsing plugin.
  + Move controls OSD to the bottom of the screen.
  + Fix fullscreen toolbar not appearing in Wayland.
  + Add Ctrl+W to quit.
  + Add man page for totem-audio-preview.
  + Fix GSettings changing on startup.
  + A number of deprecation warning fixes.
  + Build requirements grilo 0.2  changed to grilo 0.3.
- Drop totem-fix-GI-deprecations.patch and
  totem-fix-missing-return.patch; fixed upstream.
- Replace pkgconfig(grilo-0.2) BuildRequires with
  pkgconfig(grilo-0.3), following upstreams port to grilo 0.3.
* Wed Nov 18 2015 zaitor@opensuse.org
- Add totem-fix-GI-deprecations.patch: Fix some GI deprecation
  warnings (bgo#757526).
- Add totem-fix-missing-return.patch: Fix a missing return
  statement (bgo#758324).
* Mon Oct 12 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Make DVD menu navigation work again.
  + Updated translations.
* Wed Sep 30 2015 zaitor@opensuse.org
- Replace gstreamer-plugin-gstclutter for
  gstreamer-plugin-gstclutter-3_0 Requires: Totem moved to the new
  version a long time ago.
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Fix rendering bugs in the search entry.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + No major changes compared to 3.16.4.
- Changes from version 3.16.4:
  + Fix selection not working after visiting Channels page.
  + Fix MPRIS plugin following internal API changes.
  + Revert Wayland compatibility changes, it's not a required
    change in GNOME 3.16.
* Mon Aug 31 2015 zaitor@opensuse.org
- Update to version 3.16.3:
  + Fix ASF videos not being thumbnailed.
  + Bring back video inside the window under Wayland.
  + Fix Skip To dialogue not working.
  + Fix thumbnailer with newer versions of gstreamer-vaapi
    installed.
  + Update YouTube API key.
  + Updated translations.
- Drop totem-skipto-dialog.patch: Fixed upstream.
* Sun Aug 30 2015 dimstar@opensuse.org
- Add totem-skipto-dialog.patch: fix SkipTo Error: "Invalid object
  type 'TotemTimeEntry' on line 60" (boo#941102, bgo#753402).
* Mon Jun 29 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Fix popup not showing up on touchscreens.
  + Fix potential crash on 32-bit systems.
  + Updated translations.
* Thu May  7 2015 zaitor@opensuse.org
- Update to version 3.16.1:
  + Loads of performance fixes, related to thumbnailing when a
    video is playing.
  + Fix (again) doubling files added on the command-line.
  + Don't monitor the tracker source, it adds incomplete items to
    the view.
  + Fix Videos icon not showing in volume control.
  + Provide a symbolic variant of the app icon.
  + Fix frames not getting applied for new thumbnails.
  + Don't warn when video rotation is unset.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Tue Mar 17 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Update thumbnail styling.
  + Fix a crash on exit.
  + Fix application icon not showing in volume control.
  + Disable popover transitions for video menus.
  + Fix downloading subtitles with newer Python versions.
  + Updated translations.
* Wed Mar  4 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Build fixes.
  + Update appdata file.
  + Updated translations.
* Fri Feb 20 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Better missing plugins support with GNOME Software.
  + Modify appearance of source icons.
  + Make view switcher button homogeneous.
  + Use intltool to translate GSettings schema files directly.
  + Better translator comment for subtitle-encoding.
  + Remove outdated helper script, which used Python 2.
* Wed Jan 28 2015 badshah400@gmail.com
- Update to version 3.15.4:
  + Stop thumbnailing when exiting.
  + Use the theme's foreground color to render the symbolics.
  + Remove use of a number of deprecated properties.
  + Require a newer cairo for hi-dpi support.
  + Fix missing translation support in thumbnailer/gallery support.
* Wed Jan 28 2015 zaitor@opensuse.org
- Update to version 3.14.2:
  + Stop thumbnailing when starting playback.
  + Keep the controls visible when seeking with the slider.
  + Show popup when seeking with the keyboard.
  + Only show videos longer than 5 seconds.
  + Hide source which provide torrent URLs.
  + Fix translation support in thumbnailer.
  + Fix Totem doubling files added on the cmd line.
  + Handle "Powerpoint" buttons on remotes.
  + Remove spacing around preferences tabs.
* Thu Nov 20 2014 zaitor@opensuse.org
- Update to version 3.14.1:
  + Fix lingering white line in fullscreen.
  + Fix bug in MPRIS support when used via Rygel.
  + Thumbnail bookmarked movies as well.
  + Fix starting Totem via D-Bus (gnome-open).
  + Port from appdata-tools to appstream-glib.
  + Add a keyboard shortcut for starting subtitles download.
- Replace appdata-tools for appstream-glib BuildRequires following
  upstreams port.
* Mon Sep 22 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + save-file: Handle an unset Videos directory.
  + Fix popup disappearing when volume is being set.
  + Remove border from error dialogue.
  + Require newer versions of clutter-gtk and gst-plugins-base.
* Sun Sep  7 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Fix opening files following the D-Bus-ification.
  + libgd updates to fix the appearance of check boxes and subtitle
    labels.
- Changes from version 3.13.91:
  + Generate thumbnails for the videos in the main view when
    they're missing.
  + Rename totem.desktop to org.gnome.Totem.desktop
  + Updated translations.
- Add pkgconfig(gnome-desktop-3.0) BuildRequires: New dependency.
* Tue Aug 19 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Rename "Recent" section to "Videos".
  + Remove visualisation support.
  + Remove browser plugin.
  + Better error message for RTSP blocked by firewall.
  + Automatically rotate mobile phone videos.
  + Allow seeking past fill-level.
  + Postpone loading library after playback.
  + Fix headerbar title when playing search results.
  + Fix crasher on startup with newer GTK+.
  + Fix crash when browsing Euronews source.
  + Use correct icon name for "gear" menu.
  + Don't allow adding duplicate items to recent view.
  + User new "audio-filter" property.
  + Fix loading Audio CDs' Wave files.
  + Fix potential data loss when removing multiple files.
  + Reset loaded text subtitles when closing video.
  + Fix hidden cursor with visible popup.
  + Move the "un-fullscreen" button to the corner.
  + OpenSubtitles:
  - Don't throw an error when the language is unknown.
  - Fix subtitles suffix when saving it.
  - Add support for Basque.
- Drop totem-browser-plugin, totem-browser-plugin-gmp and
  totem-browser-plugin-vegas subpackages: the browser integration
  has been dropped by upstream. Obsolete the same by totem.
- Drop totem-use_right_names.patch: fixed upstream.
- Drop gnome-common BuildRequires and call to autoreconf: no patch
  touches the buildsystem.
* Tue Aug 19 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Postpone loading library after playback.
  + Fix headerbar title when playing search results.
  + Fix crasher on startup with newer GTK+.
  + Fix crash when browsing Euronews source.
  + Don't allow adding duplicate items to recent view.
  + Fix loading Audio CDs' Wave files.
  + Fix potential data loss when removing multiple files.
  + Reset loaded text subtitles when closing video.
  + Fix hidden cursor with visible popup.
  + OpenSubtitles:
  - Don't throw an error when the language is unknown.
  - Fix subtitles suffix when saving it.
  - Add support for Basque.
- Drop totem-use_right_names.patch, fixed upstream.
* Sat Jul 26 2014 dimstar@opensuse.org
- Add totem-use_right_names.patch: Use the correct name for
  parent widgets in templates. Fixes crash on startup (bgo#729479).
* Wed Apr 30 2014 dimstar@opensuse.org
- Update to version 3.12.1:
  + Bump required versions of grilo and GStreamer.
  + Fix delete button's initial state.
  + Switch to the player view quicker.
  + Add support for starting a playlist paused.
  + Escape selection mode when pressing Esc.
  + Fix shuffled items starting to play in random order.
  + Hide popups when leaving the window, but not when a popover
    (volume, menus) is visible.
  + Don't toggle popups on touchpad clicks, just on touchscreens.
  + Fix scroll-wheel going forward 2 minutes instead of 1.
  + Save the downloaded subtitles in the video directory.
  + Re-add drag'n'drop support for the video widget.
- Drop pkgconfig(gnome-icon-theme) BuildRequires: no longer
  required.
* Mon Mar 24 2014 dimstar@opensuse.org
- Update to version 3.12.0:
  + Fix artifacts caused by GtkPopovers.
  + Don't add containers in the Recent view.
  + Various opensubtitles plugin bug fixes.
  + Updated translations.
* Tue Mar 18 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Use popovers for menus, and remove their shadows.
  + Hide popups after 2 seconds not 5.
  + Fix crashers when deleting items.
  + Only resolve using the passed source.
  + Remove stock icons usage.
  + Don't offer to save file in ~/Videos subdirs.
  + Fix empty window title in some cases.
  + Fix handling of kbd shortcuts with multiple modifiers.
  + Blacklist adult sources for now.
  + Fix ngettext usage.
  + Avoid queueing multiple thumbnail updates.
  + Add names to timeouts and idles.
  + Don't monitor the filesystem plugin.
  + Updated translations.
* Tue Feb 18 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Add sideways swipe gestures to seek inside the window.
  + Move Open/Add menu items to the "Add" button.
  + Add drop support to the "Recent" section of the overview.
  + Implement "Make Available Offline".
  + Maximise window by default.
  + Make F10 show the gear menu.
  + Make Ctrl+F toggle the search mode.
  + Handle the "Play DVD" remote control key.
  + Pause playback when the screensaver comes on.
  + Correct spacing and title of the preferences window.
  + Remove film strip by default from thumbnails, nautilus will add
    them itself if necessary.
  + Fix monitoring of Grilo sources.
  + Show switcher buttons when turning on search.
  + Ensure the buffering spinner gets removed when closing a file.
* Wed Feb  5 2014 dimstar@opensuse.org
- Update to version 3.11.5:
  + Complete redesign.
- Drop gstreamer-plugins-bad BuildRequires: it's also listed as
  pkgconfig(gstreamer-plugins-bad-1.0).
- Drop pkgconfig(ice) and pkgconfig(sm) BuildRequires: smclient
  support was removed.
- Drop pkgconfig(dbus-glib-1) BuildRequires: no longer needed.
- Add appdata-tools BuildRequires: new dependency to validate the
  appdata file.
- Add gnome-common BuildRequires and call to autoreconf: the
  tarball was bootstrapped with an older version of appdata-tools,
  which did not have the --nonet parameter (and as a consequence
  expects internet access).
* Mon Sep 30 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Fix possible abort on startup.
  + Fix warning on startup.
- Drop totem-git-fixes.patch: fixed upstream.
* Sun Sep 29 2013 dimstar@opensuse.org
- Add totem-git-fixes.patch: Backport three fixes from git, fixing
  minor errors messages on startups and the possibility of an
  assert on launch (bgo#708647).
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Wed Sep 18 2013 zaitor@opensuse.org
- Update to version 3.9.92:
  + RTL bug fixes for playback icons.
  + Fix year tag not showing in some cases.
  + Remove obsolete totem-disc usage.
  + Port zeitgeist plugin to zeitgeist-2.0.
- Exchange pkgconfig(zeitgeist-1.0) BuildRequires for
  pkgconfig(zeitgeist-2.0) BuildRequires following upstreams port.
* Mon Jul 29 2013 dimstar@opensuse.org
- Update to version 3.9.5:
  + Add work-around to allow streaming of Vimeo videos.
  + Don't hide the titlebar on fullscreen (as we still have a menu
    bar).
  + Make thumbnailer work even when VA-API support is enabled.
  + Avoid warnings from the rotation plugin for unsupported
    locations.
  + Fix aspect ratio in dual-head setups.
  + Fix playback when video location is not mounted.
  + Access streams directly rather than through FUSE, making
    buffering and playback smoother.
  + Fix excessive redraws when using rotation, and make rotation
    and crop work together.
* Tue May 14 2013 dimstar@opensuse.org
- Update to version 3.8.2:
  + Work-around problem with initial window size.
  + Fix errors in gallery name print when filename contains "&".
  + Fix translations not being applied in nautilus' properties.
  + Fix Python Console not working.
  + Fix screenshot keyboard shortcut.
* Fri May  3 2013 dimstar@opensuse.org
- Remove pkgconfig(mx-1.0) BuildRequires: no longer needed since
  version 3.5.90.
* Tue Mar 26 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Wed Mar 20 2013 dimstar@opensuse.org
- Update to version 3.7.93:
  + Fix incorrect Vala generated files getting in the release.
- Change build_zeitgeist_plugin back to 1, as the issue was fixed
  by upstream.
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Use yelp-tools instead of gnome-doc-utils.
  + Add YouTube format configuration for grilo.
  + Fix possible Unicode errors with MPRIS plugin.
  + Use libgd's icon view for search results.
  + Fix warnings for some files in the browse sidebar.
  + Fix possible crashes in the chapters plugin.
  + Fix playing audio CD tracks launched from Nautilus.
  + Fix running when clutter-gst is in a different prefix.
  + Plugins: Remove use of deprecated widgets in subtitles
    downloader.
- Drop upstream fixed patches:
  + totem-Use-Ctrl+C-as-the-shortcut.patch
  + totem-Fix-playing-files-from-recent-files.patch
  + totem-Fix-fetching-the-cover-art.patch
- Replace gnome-doc-utils-devel BuildRequires with yelp-tools,
  following upstream.
- Change build_zeitgeist_plugin to 0 for now, as the tarball is
  broken and building the plugin does not work.
- Drop --disable-maintainer-mode and --disable-scrollkeeper
  configure parameters: no longer needed.
- Add gstreamer-plugins-bad Requires: needed for the scaletempo
  plugin (bnc#809854, bnc#810376).
* Sat Feb  9 2013 zaitor@opensuse.org
- Add totem-Use-Ctrl+C-as-the-shortcut.patch; So as not to clash
  with Eject which already uses Ctrl+E (bgo#688298).
- Add totem-Fix-playing-files-from-recent-files.patch; Loads of
  confusion as to the playback path for trash:/// and recent:///
  would cause an assertion when drag'n'dropping such a file.
  (bgo#690304).
- Add totem-Fix-fetching-the-cover-art.patch; Initialise the type
  of image so that we can save the cover image even if the
  image-type isn't defined. (bgo#690286).
* Thu Nov  8 2012 dimstar@opensuse.org
- Update to version 3.6.3:
  + Really stop using the soundpitch plugin.
  + Fix playback of some audio types failing.
* Thu Oct 25 2012 dimstar@opensuse.org
- Update to version 3.6.2:
  +  Make Ogg video streaming work again (the soundpitch plugin in
    gst-plugins-bad is broken).
  + Fix memory leaks when using download buffering.
- Changes from version 3.6.1:
  + Movie Player:
  - Fix spinning cursor when launching videos from the file
    manager.
  - Fix bugs in video searches.
  + Browser Plugin:
  - Fix screensaver not being inhibited.
  - Fix some streams' video canvas being hidden.
- Add pkgconfig(gstreamer-plugins-bad-1.0) BuildRequires: new
  verified dependency, so it can be versioned.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Browser Plugin: Fix the plugin not loading correctly
  + Properties: Fix memory leaks.
* Sun Sep 23 2012 coolo@suse.com
- Replace ';' with 'and' in license tag.
* Tue Sep 18 2012 dimstar@opensuse.org
- Update to version 3.5.92:
  + Backend:
  - Fix duration conversion
  - Simplify GStreamer helpers
  - Fix warning related to g_object_unref()
  + Browser plugin:
  - Fix broken UI because of the new GtkMenuButton
  + Main:
  - Remove documentation list from "About" dialogue
  + Properties:
  - Fix string leaks.
* Thu Sep 13 2012 dimstar@opensuse.org
- Add gstreamer-plugin-gstclutter Requires: totem checks for the
  availability of cluttersink. Totem fails to start without it.
* Wed Aug 22 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + Plenty of build fixes to make it possible to build with Wayland
    support
  + Increase thumbnail size to 256 px
  + Movie player:
  - Rename to "Videos"
  - Hide titlebar when maximised
  - Move some menu items to the app menu
  - Command-line parsing bug fixes
  - Use Grilo to list DVDs and other optical media
  - Remove connection speed preferences
  - Stop DVD playback when disc is ejected
  - Fix ordering of the playlist after drag'n'drop
  + Backend:
  - Port to GStreamer 1.0
  - Add HTTP proxy support
  - Much improved error messages
  - Add variable rate playback
  - Use Clutter for the OSD
  - Disable visualisations by default
  - Animate rotations
  - Add av-offset support
  - Prepare the ground for chapter support in non-DVDs
  + Plugins:
  - Make screenshot UI-less, like in gnome-shell
  - Simplify the screensaver and browser plugin code
  - Remove publish and iPlayer plugins
  - Use Grilo 0.2
  - Better search sidebar
  - Add hook for site-specific user-agents
  - Add hook for custom subtitle selection through plugins
  - Move recent-files handling to a plugin.
- Drop xz BuildRequires as it now comes for free in the build
  system.
- Add pkgconfig(gsettings-desktop-schemas) BuildRequires: new
  dependency.
- Replace BuildRequires for the port to GStreamer 1.0:
  + Old: gstreamer-0_10-plugins-base, gstreamer-0_10-plugins-good,
    pkgconfig(gstreamer-0.10),
    pkgconfig(gstreamer-plugins-base-0.10) and
    pkgconfig(gstreamer-tag-0.10)
  + New: gstreamer-plugins-bad, gstreamer-plugins-good,
    pkgconfig(gstreamer-1.0), pkgconfig(gstreamer-plugins-base-1.0)
    and pkgconfig(gstreamer-tag-1.0)
- Replace pkgconfig(grilo-0.1) BuildRequires with
  pkgconfig(grilo-0.2)
- Replace pkgconfig(clutter-gst-1.0) BuildRequires with
  pkgconfig(clutter-gst-2.0)
- Remove libXtst-devel BuildRequires: the dependency got dropped
  with the cleanup for Wayland.
- Remove unneeded explicit gstreamer-0_10 Requires, and change
  gstreamer-0_10-plugins-{base,good} Requires to
  gstreamer-plugins-{base,good}.
* Fri Aug 17 2012 dimstar@opensuse.org
- Use upstream name Movie Player, fixes bnc#772554.
  Having a different name for the desktoplauncher and what the
  application is named could confuse users.
* Wed Jul  4 2012 dimstar@opensuse.org
- Update to version 3.4.3:
  + Fix sidebar related warnings on startup.
  + Fix thumbnailer hanging on errors.
  + Fix problems scrolling with mouse scroll wheels.
* Tue May 15 2012 vuntz@opensuse.org
- Update to version 3.4.2:
  + Make "Esc" focus the video widget if the sidebar button was
    selected
  + Updated translations.
* Mon Apr 16 2012 zaitor@opensuse.org
- Update to version 3.4.1:
  + Remote option argument parsing fixes.
  + Fix for keyboard shortcuts when using ModeSwitch.
  + Updated translations.
* Tue Mar 27 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Mark some strings as translatable
  + Handle Clutter failing to initialise
  + Don't handle Ctrl+Space (which is used for IM switching)
* Sun Mar 18 2012 dimstar@opensuse.org
- Update to version 3.3.92:
  + Check plugins for introspection in configure.
* Mon Feb 20 2012 vuntz@opensuse.org
- Update to version 3.3.90:
  + Show Vorbis DESCRIPTION field in Comments
  + Use GTK+ code to detect the workspace's work area
  + Do use direct seeking for files in the wastebasket
  + Thumbnail FLAC files too
  + Fix crash when using MPRIS plugin
  + Fix compilation of the rotation plugin with newer Vala
- Add explicit BuildRequires after xorg-x11 packaging change:
  libXtst-devel, pkgconfig(x11).
- Remove unneeded BuildRequires: pkgconfig(xrandr),
  pkgconfig(xxf86vm).
* Tue Feb  7 2012 vuntz@opensuse.org
- Simplify a bit some subpackage summaries.
* Sun Feb  5 2012 zaitor@opensuse.org
- Move vegas browser plugin to new browser-plugin-vegas subpackage:
  this plugin doesn't work on all video flash websites, and
  breaking websites is bad. Having this as a subpackage makes it
  easy for people who want it to have it.
- Note that Enhances is used instead of Supplements (like other
  browser plugin subpackages) to not have it installed by default.
* Wed Dec 21 2011 vuntz@opensuse.org
- Update to version 3.3.4:
  + Re-enable and fix compilation of zeitgeist-dp plugin
  + Use new GLib threading API if compiling with GLib ≥ 2.31.0
  + Fix some problems with `make check` on the Python plugins
- Set %%build_zeitgeist_plugin macro to 1.
- Remove hack in %%setup that was touching
  src/plugins/zeitgeist-dp/Makefile.in to fix the build: fixed
  upstream.
* Tue Dec 20 2011 vuntz@opensuse.org
- Update to version 3.3.3:
  + Add plugin to replace the Flash plugin for online videos
  + Add support for RTMP URLs
  + Fix vala plugins compilation
  + Fix --time option in thumbnailer
  + Fix possible crashes with the browser plugin on OpenBSD
  + Remove obsolete youtube and bemused plugins
  + Port browser plugin to GDBus
  + Fix getting the cover art in the movie player
  + Fix crasher when Totem is passed arguments
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Remove pkgconfig(bluez) and pkgconfig(libgdata) BuildRequires:
  removed upstream.
- Add a %%build_zeitgeist_plugin macro to enable/disable the build
  of the zeitgeist plugin. If unset:
  + do not create the totem-plugin-zeitgeist subpackage
  + do not use pkgconfig(zeitgeist-1.0) BuildRequires
  + add a totem-plugin-zeitgeist Obsoletes to totem for smooth
    upgrades
- As there are build issues caused by the zeitgeist plugin (it's
  not in the tarball):
  + set %%build_zeitgeist_plugin to 0
  + touch src/plugins/zeitgeist-dp/Makefile.in in %%setup to avoid a
    build failure
* Mon Oct 17 2011 dimstar@opensuse.org
- Update to version 3.2.1:
  + Fix crash when framerate isn't available
  + Quieten the thumbnailer when thumbnailing non-videos
  + Updated translations.
* Sat Oct 15 2011 andrea.turrini@gmail.com
- Fix typos in descriptions.
* Fri Sep 30 2011 dimstar@opensuse.org
- Remove sed hack in %%prep to support building with libepc 0.4.0 as
  we have libepc 0.4.1 available now.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Fix Python console settings conversion bug
  + Updated translations.
* Wed Sep 21 2011 vuntz@opensuse.org
- Update to version 3.1.92:
  + Mention our support of a few more mime-types
  + Handle HTTP Live Streaming (in the main player, and the browser
    plugin)
  + Updated translations.
- Pass --disable-maintainer-mode to configure as a workaround: this
  lets use deprecated GTK+ API for now. We should not keep this
  flag in the long term, though.
* Tue Sep 13 2011 vuntz@opensuse.org
- Update to version 3.1.91:
  + Port D-Bus service to MPRIS 2.1
  + Store and restore the rotation status of videos
  + Fix the "save" button not work in the playlist
  + Screensaver fixes for non-GNOME sessions
  + Port to pygobject 3.0
- Change pkgconfig(pygobject-2.0) BuildRequires to
  pkgconfig(pygobject-3.0), following upstream change.
- Add a sed hack in %%prep, to support building with libepc 0.4.0:
  since there is no new release of libepc, we added the patches
  from git that totem needs, so we can build with 0.4.0 now.
* Wed Aug  3 2011 dimstar@opensuse.org
- Update to version 3.1.4:
  + Add Grilo plugin
  + Remove Coherence UPNP, Tracker and Jamendo plugins
  + Add plugin to rotate videos
  + Fix audio tracks not appearing with their language names
  + Add keyboard shortcut for "Save"
  + Remove sidebar drop-down item, and use menu items instead
  + Fix translations of the nautilus properties window
  + Subtitles plugin bug fixes
- Add pkgconfig(grilo-0.1) BuildRequires for the new grilo plugin
- Remove the disabled plugin-upnp package. Grilo is the new
  framework also taking over the UPnP capabilities and the plugin
  is in the main package. Obsolete totem-plugin-upnp by totem main
  package.
- Drop patches:
  + totem-libgdata-0.9.patch: fixed upstream
  + totem-gdk-multibackend.patch: fixed upstream
- Remove gnome-common BuildRequires and call of gnome-autogen.sh,
  as we don't have any patches left.
* Thu Jul  7 2011 vuntz@opensuse.org
- Add totem-libgdata-0.9.patch: fix build against libgdata 0.9.x,
  taken from git. Add call to gnome-autogen.sh to have it taken
  into account.
- Add totem-gdk-multibackend.patch: fix detection of gdk backend to
  support GTK+ built with multiple backends, taken from git.
- Stop building the tracker plugin to fix build:
  + it got removed upstream in git, so it will be gone in the next
    version anyway; and the current version requires tracker 0.10
    while we moved to 0.11.
  + remove pkgconfig(tracker-client-0.10) BuildRequires (or
    pkgconfig(tracker-client-0.8) on old versions).
* Fri May 27 2011 vuntz@opensuse.org
- Package zeitgeist plugin:
  + add vala and pkgconfig(zeitgeist-1.0) BuildRequires.
  + create a plugin-zeitgeist subpackage.
- Fix Supplements in plugin-upnp to not mention %%{totem}, which
  can't work, but %%{name}.
* Mon May 16 2011 dimstar@opensuse.org
- Update to version 3.1.0:
  + Use clutter-gst to draw the video, the only major related
    change is simpler zoom modes
  + Use GStreamer API directly for audio preview utility (used in
    nautilus), thumbnailer and nautilus properties window
  + Show container format in the properties
  + Add ability to switch video tracks
  + Add ability to "thumbnail" DVD ISOs
  + Advertise support for audio/x-stm and audio/x-s3m
  + Fix possible dropped chapters in chapter plugin
  + Code changes:
  - Port media-player-keys plugin to GDBus
  - Add pylint support for all Python plugins, and fix errors
    from it, and port all of the plugins to GObject Introspection
  - Simplify screenshot code
  + Remove XVidMode support in backend
  + Remove video indexer: it wasn't used
  + Remove thumbnail plugin which doesn't serve a purpose in GNOME3
- Add gnome-dvb-daemon Suggests, as it's a nice addon.
- Add newly-needed pkgconfig(clutter-1.0),
  pkgconfig(clutter-gst-1.0), pkgconfig(clutter-gtk-1.0) and
  pkgconfig(mx-1.0) BuildRequires.
* Wed Apr 27 2011 fcrozat@novell.com
- Update to version 3.0.1:
  + Fixes to chapters plugin which resulted in missing chapters.
  + Fix translations in filter drop-down for save dialogue.
  + Fix gallery mode's last picture never appearing.
  + Fix possible crasher in save-file plugin.
  + Updated translations.
* Tue Apr 26 2011 vuntz@opensuse.org
- Use standard libexecdir instead of passing
  - -libexecdir=%%{_libexecdir}/totem to configure.
- Change pkgconfig() BuildRequires: gtk+-2.0 to gtk+-3.0.
* Mon Apr  4 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + Fix packing and spacing in the properties
  + Fix subtitle downloader and jamendo plugins
  + Updated translations.
* Mon Mar 28 2011 fcrozat@novell.com
- Update to version 2.91.93:
  + Fix activation of all Python plugins
  + Make Python console work again
  + Updated translations
- Changes from version 2.91.92:
  + Plenty of screensaver related bug fixes
  + Make "Open Location" dialogue modal
  + Never use an empty User-Agent in the backend
  + Don't poke at web server when we already have information to
    set up "recent files"
- Changes from version 2.91.91:
  + Fix screensaver for latest gnome-screensaver
  + Fix possible assertion in save-file plugin
  + Use gnome-session instead of Galago for status notifications
  + Fix thumbnailer with both --size and --raw options
  + Require GTK+ 3.x in pkg-config file, and fix compilation for
    out-of-tree plugins
  + Make sure all the builtin plugins get activated on startup
  + Fix screenshot for interlaced videos
  + New icon
- Changes from version 2.91.7:
  + Allow finer-grained control on the volume using Shift as a
    modifier
  + Add Zeitgeist provider plugin
  + Don't crash if plugins weren't loaded
  + Update work area code
  + Update for latest libpeas changes
  + Make default plugins dialogue bigger
  + Fix saving localised strings in the chapters CMML files
  + Fix vanishing entries when loading mixed media types from slow
    links
  + Fix screensaver not disabling when switching to fullscreen
    straight away
- Changes from version 2.91.6:
  + YouTube plugin:
  - Show actual stream title instead of "videoplayback" in the
    recent items menu
  + Fix build with latest GTK+ version
  + Various build fixes
- Changes from version 2.91.5:
  + Build:
  - Fix build with newer versions of GTK+ 3.x
  + Thumbnailer:
  - Register thumbnailer with new scheme
  - Always use the better looking resize method, even for
    large thumbnails
  + Movie Player:
  - Use new-style toolbar for playlist
  - Fix look of plugins preferences
  - Notice panels when automatically resizing the window
  + Plugins:
  - Fix subtitles plugin not closing after download
  - Downgrade YouTube plugin's abilities, to respect Terms of
    Service.
  - Offer to launch YouTube in browser if video is not
    available in the requested format.
  - Re-add support for Vala plugins and sample vala plugin
  - Add support for additional multimedia keys
  - Port tracker plugin to newest API
  + Browser plugin:
  - Fix possible crasher in the glow button
- Changes from version 2.91.4:
  + Build:
  - Port to GtkStyleContext
  - Other GTK+ 3.x fixes
  + Movie Player:
  - Remove the MythTV plugin (upstream is dead and UPnP works
    just as well)
  - Change the data paths in GSettings schemas
  - Lots of Python plugin fixes
  - Add a save file plugin
  - Fix a race condition when parsing multiple playlist entries
  - More GSettings fixes and cleanup
  - Use symbolic icons for the volume level
  - Fix plugin shutdown
  + GStreamer backend:
  - Various drawing fixes
- Changes from version 2.91.0:
  + List audio/mp2 as supported
  + Build:
  - Use upstream gettext instead of GLib's
  - Plenty of bug fixes for building against GTK+ 3.x
- Changes from version 2.90.6:
  + Movie Player:
  - Re-enable Python plugins
  - Update for libpeas and GTK+ 3.x changes
  - Add chapters plugin
  - Use icon for the sidebar
  - Don't try to load subtitles, or chapters data for streams
  - Only popup controls when the mouse moves a certain distance
  - Port to GSettings
  + YouTube plugins:
  - Fix playback again
  - Support Web-M videos
  - Hide URLs from the tooltips, they're not useful
  + GStreamer backend:
  - Don't block main thread when seeking
  + Thumbnailer:
  - Use msecs instead of seconds for seeking, which should fix
    black frames
  - Make --raw work along with --size, so you can avoid adding
    borders
- Changes from version 2.90.5:
  + Movie Player:
  - Port from libunique to GApplication
  - Rework cancellation in the YouTube plugin to remove races
  - Reorganise the core code into an installed library,
    libtotem.so
  - Add gobject-introspection support to this library
  - Make it possible to build plugins out of tree by installing
    a few header files
  - Remove the old Python and Vala bindings in favour of
    introspection
  - Port the Python plugins to libpeas and the new bindings
  - Tidy up the "Open Location" dialogue
  - Port to the updated PeasUIConfigurable interface in libpeas
    0.5.2
  + Browser plugin:
  - Add support for the VLC input.length property
- Changes from version 2.90.0:
  + Movie Player:
  - Fix some strings in the BBC iPlayer plugin
  - Support async loading of playlists
  - Fix window resizing when showing/hiding the controls and
    sidebar
  - Add deinterlacing to the preferences
  - Add support for accurate seeking
  - Add WebM support
  - Port to GDBus
  - Port to libpeas for plugin handling (porting the C plugins,
    but disabling the Python and Vala ones)
- Drop totem-URI-scheme-handler-support.patch: fixed upstream.
- Drop totem-fix-scheme-handler.patch: fixed upstream.
- Remove the sed that was used to support tracker 0.10: fixed
  upstream.
- No longer use vala-devel BuildRequires: vala sample plugin is not
  longer installed (and not useful anyway).
- Update pkgconfig() BuildRequires:
  + Drop gconf-2.0, unique-1.0.
  + Change pygtk-2.0 to libpeas-1.0 and pygobject-2.0.
- Replace GConf2 schemas handling with GSettings schemas handling,
  with %%glib2_gsettings_schema_* macros.
- Disable upnp plugin (with the enable_upnp_plugin define):
  coherence still requires pygtk which conflicts with new pygobject
  introspected bindings.
- Add /sbin/ldconfig to %%post/%%postun as there is now a library.
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Remove ldconfig from %%post/%%postun: there is no library here.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Mon Jan 17 2011 vuntz@opensuse.org
- Change pkgconfig(tracker-client-0.9) BuildRequires to
  pkgconfig(tracker-client-0.10) to fix build on Factory.
- On 11.4 and later, change configure to look for
  tracker-client-0.10 instead of tracker-client-0.9, since that is
  the right name to use now.
* Wed Nov 24 2010 badshah400@gmail.com
- Added upstream patches totem-URI-scheme-handler-support.patch and
  totem-fix-scheme-handler.patch to fix URI scheme handler support
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 2.32.0:
  + Updated translations.
* Sat Sep 18 2010 vuntz@opensuse.org
- Update to version 2.31.92.2:
  + Port back from GApplication to libunique.
- Add pkgconfig(unique-1.0) BuildRequires.
* Sat Sep 18 2010 vuntz@opensuse.org
- Update to version 2.31.92.1:
  + Fix a couple more uses of deprecated GDK API
* Thu Sep 16 2010 vuntz@opensuse.org
- Update to version 2.31.92:
  + Stop using deprecated GDK API
  + Some minor plugin documentation fixes
  + Updated translations
* Mon Sep 13 2010 vuntz@opensuse.org
- Update to version 2.31.90:
  + Add chapters plugin
  + Support Web-M videos in YouTube plugin
  + Fix possible crash when quitting whilst the stream's tags are
    being gathered
  + Make it possible to use --raw along with --size in thumbnailer
  + Loads of updated translations
* Tue Sep  7 2010 vuntz@opensuse.org
- Remove unneeded evolution-data-server-devel,
  gnome-control-center-devel, gnome-desktop-devel, scrollkeeper
  BuildRequires.
- Change old-style BuildRequires to pkgconfig() style
  BuildRequires:
  + old-style: bluez-devel, dbus-1-glib-devel,
    gnome-icon-theme-devel, gstreamer-0_10-plugins-base-devel,
    iso-codes-devel, libepc-devel, libgdata-devel, nautilus-devel,
    python-gtk-devel, shared-mime-info-devel,
    totem-pl-parser-devel, tracker-devel.
  + new-style: bluez, cairo, dbus-glib-1, gconf-2.0, glib-2.0,
    gnome-icon-theme, gstreamer-0.10, gstreamer-plugins-base-0.10,
    gstreamer-tag-0.10, gtk+-2.0, ice, iso-codes, libepc-ui-1.0,
    libgdata, libnautilus-extension, libxml-2.0, pygtk-2.0,
    shared-mime-info, sm, totem-plparser, tracker-client-0.9,
    xrandr, xxf86vm.
- This will make it easier to switch to GNOME 3 libraries.
* Thu Aug 12 2010 dimstar@opensuse.org
- Update to version 2.31.6:
  + Add support for Web-M to browser, movie player, and YouTube
    plugin
  + Movie Player:
  - Add deinterlacing support, automatically used for interlaced
    content
  - Do not block when loading playlists
  - Remove libunique dependency
  - Make auto-resize use half-scale or 2x if the player would
    fit on the screen
  - Make screensaver preference clearer
  - Support running with RGBA (semi-transparent) GTK+ themes
  + Plugins:
  - Update for YouTube website changes
  + Browser plugin:
  - Fix running browser plugin in non-GTK+ front-ends
  + VLC-compatible browser plugin:
  - Support input.time and input.length property
  - Support togglePause function
  - Support toolbar plugin argument
- Remove libunique-devel BuildRequires.
* Fri Jun 25 2010 vuntz@opensuse.org
- Add libepc-devel and tracker-devel BuildRequires to build the
  publish and tracker plugins.
- Do not package /usr/lib/totem/totem-plugin-viewer twice, and
  instead make the browser-plugin-gmp subpackage depend on the
  browser-plugin subpackage.
* Fri May 28 2010 vuntz@opensuse.org
- Split upnp plugin in plugin-upnp subpackage: it depends on
  python-coherence, which depends on python-twisted, which is quite
  big.
- Add totem-plugin-upnp Suggests to the main package.
- Move the sample-vala plugin to the devel subpackage.
* Wed May 12 2010 dimstar@opensuse.org
- Update to version 2.30.2:
  + Movie Player:
  - Fix huge window height when hiding then showing controls
    again
  - Fix slight resize when showing the sidebar for the first time
  - Fix possible crash when loading PytGTK
  - Fix loading OSD icons when there's no SVG versions
  + Browser Plugin:
  - Fix volume being at zero when starting playback
  - Fix use of URL parameter for the Window Media Player
    compatibility plugin
  - Fix position on End-Of-Stream when using the QuickTime
    compatibility plugin
  + GStreamer backend:
  - Try not to block the UI when seeking
  - Fix constant buffering when playing live streams.
* Thu Apr 29 2010 dimstar@opensuse.org
- Update to version 2.30.1:
  +  Movie Player:
  - Fix artifacts and flashing or black screen when paused
  - Better download buffering handling
  - Fix crasher when PyGTK is badly installed
  - Avoid problems with seeking when pausing the video too early
  - Fix link to Totem website in error messages
  - Disable seeking in DVD menus
  - Make Eject menu item work for DVDs
  - Fix playback from FTP sites
  + Plugins:
  - Port Tracker plugin to Tracker 0.8
  - Make YouTube plugin work again for latest site changes
  + Browser Plugin:
  - Add download buffering support even when streaming from
    the browser itself
  - Fix playback on the Apple trailers site, and add seeking
    support.
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 2.30.0:
  + Updated translations.
* Tue Mar 16 2010 bgmerrell@novell.com
- Split Windows Media (gmp) plugins into a new package named
  totem-browser-plugin-gmp.  This new package will conflict with
  Moonshine.
* Mon Mar 15 2010 dimstar@opensuse.org
- Update to version 2.29.92:
  + Fix some possible hangs when switching files.
* Thu Feb 25 2010 dimstar@opensuse.org
- Update to version 2.29.91:
  + Fix compilation with newer versions of Tracker
  + Update time in the status bar when frame-stepping
  + Fix a lot of build problems with newer GTK+, or using pedantic
    linkers
  + Update Vala bindings for external plugins
  + Fix problems with the popup menu in the browser plugin
- Drop totem-no-gstreamer-snapshot.patch, as we have more recent
  gstreamer already.
* Wed Jan 27 2010 vuntz@opensuse.org
- Update to version 2.29.4:
  + Fix documentation build
- Changes from version 2.29.3:
  + Movie Player:
  - Add GConf key to disable all the keyboard shortcuts
  - Implement type-ahead search
  - Display embedded cover images in audio streams
  - Add "fullscreen" button in the main video UI
  - Fix for new TotemPlParser API
  - Fix the time elapsed not showing up in the status bar with
    newer GTK+
  - Fix translation of skip menu items in RTL languages
  - Make "Esc" passing the keyboard focus to the video canvas
  - Close RTSP streams, and clean up temporary buffer files on
    exit
  + Web browser plugin:
  - Fix a number of Javascript functions not working in the
    QuickTime plugin
  - Implement SetURL for QuickTime
  + Plugins:
  - Remove built-in DVB support, and rely on gnome-dvb-daemon
    instead
  - Convert D-Bus plugin to MPRIS plugin
  + GStreamer backend:
  - Fix playback of files from archives
  - Make track switching faster
* Sat Jan 16 2010 vuntz@opensuse.org
- Do not package en@shaw locale on openSUSE 11.2 and earlier.
- Do not add DocPath to the .desktop file: yelp doesn't use this
  anymore.
* Thu Dec 24 2009 vuntz@opensuse.org
- Update to version 2.29.2:
  + General:
  - Add disk buffering for QuickTime and Flash video files, and
    only start playing the file when it can be played
    uninterrupted until the end
  - Add support for authentication for HTTP and RTSP streams
  - Make track switching faster
  - Don't save the volume anymore, the sound system should
  - Use cairo to draw the logo
  + Movie Player:
  - Add OSD when keyboard or remote keys are pressed
  - Add support for reverse frame-stepping
  - Add support for playing back DVDs and VCDs from mounted ISO
    images
  - Include the movie name when taking screenshots
  - Use gallery instead of screenshot in suggested gallery file
    names
  + Browser plugin:
  - Use referrer information
  - Add support for subtitles in the VideoLAN API
  - Remove "Complex" (RealMedia compatible) plugin
- Remove --disable-complex-plugin option from configure.
- Use libexecdir instead of prefix/lib.
- Fix rpmlint warning about self-obsoletion of totem-plugin.
- Add totem-no-gstreamer-snapshot.patch to make this tarball build
  with the latest gstreamer release, instead of a snapshot. This is
  obviously not optimal, but it's the simplest workaround.
* Fri Dec  4 2009 dimstar@opensuse.org
- Update to version 2.28.4:
  + Movie Player:
  - Don't hide the fullscreen popups when the mouse is on top of
    them
  + Thumbnailer:
  - Fix covers not being used any more
  + Web browser plugin:
  - Fix potential crasher when using Javascript bindings
  - Fix resolution of absolute URL
- Changes from versin 2.28.3:
  + Movie Player:
  - Fix position saving when skipping to the next item in the
    playlist
  - Allow playback of Apple trailers in the movie player
  - Fix behaviour with only one item in the playlist and its
    playback finishes
  + YouTube plugin:
  - Fix for latest website changes
  + GStreamer backend:
  - Clean up volume handling
  - Fix aspect ratio warnings with some streams
  - Fix tags being associated with the wrong file when an error
    occurs
- Changes from version 2.28.2:
  + Movie Player:
  - Fix possible crash on exit when using Python plugins
  - Fix warning when displaying file tooltip in the playlist
  - Fix help links not showing up in error messages
  - Fix "disabling screensaver when audio is playing" checkbox
    never turning off (or on)
  - Fix play order when removing currently playing song
  + Web browser plugin:
  - Fix screensaver not being stopped when playing movies
  - Fix parsing of playlist files when using WebKit
  - Add support for midi files
  + GStreamer backend:
  - Fix possible hang on startup
  - Fix DVB channels file not being detected properly
  - Fix warning when creating a screenshot
  - Use cubic volumes when PulseAudio is used
  - Fix intermittent pixel-aspect-ratio warnings
* Wed Sep 30 2009 vuntz@opensuse.org
- Update to version 2.28.1:
  + Movie Player:
  - Fix some problems with the "remember position" feature,
    disable it by default to avoid confusion
  + Web browser plugin:
  - Fix problems with cached files disappearing when using WebKit
  + GStreamer backend:
  - Fix memory leak when taking screenshot
* Tue Sep 22 2009 dimstar@opensuse.org
- Update to version 2.28.0:
  + Use name from the playlist for the recent item
  + Set the stream volume using PulseAudio
  + Fix a crash in the web browser plugin with WebKit
  + Fix playback of YouTube videos
  + Fix possible hangs after playing a remote file
* Wed Sep  9 2009 vuntz@opensuse.org
- Update to version 2.27.92:
  + Movie Player:
  - Remember the current file position when Pause is clicked
  - Show menu item description in status bar
  - Make Home and End keys seek to the start and the end of
    streams
  - Use Totem's icon as the main window logo
  - Make screenshot dialogue more like GNOME's
  - Bug fixes:
  * Fix crash when a storage volume is encrypted
  * Make shuffle playlists faster with a large number of items
  * Fix the artist not showing up in the window title
  * Detect non-xine DVB channel configurations
  * Select the directory in which the movie is by default,
    when looking for a subtitle
  + Web browser plugin:
  - Use the user-agents for the plugins we're mimicking
  - Show controls for the Cone plugin when VLC compatibility
    isn't explicitely asked
  + Thumbnailer:
  - Make it possible to output thumbnails without the film
    borders
  + Plugins:
  - Add plugin authoring tutorial
- Add vala-devel BuildRequires to get vala support for plugins.
* Mon Aug  3 2009 dominique-obs@leuenberger.net
- Update to version 2.27.2:
  + Movie Player:
  - Add frame-by-frame stepping
  - Better fallback names for audio and languages tracks
  - Make the arrow keys navigate DVD menus when one is loaded
  - Move subtitles-related menu items to View → Subtitles.
  - Bug fixes:
  * Fix loading subtitles from the cache
  * Fix loading videos when Totem is already running
  * Fix drag'n'dropping a video onto itself reloading the video
  * Only add a file to the recent files when it has been played
    makes startup with loads of files much quicker
  + GStreamer backend:
  - Prevent tags from other tracks to show up when
    they're not used
  - Try to mount the location where the file is when it's
    not already mounted
  + YouTube plugin:
  - Fix a possible crasher when loading thumbnails
  - Fix problems in non-English locales
  - Fix video list rendering problems
  + Fix UI differences between the YouTube, Jamendo and local seach
    plugins
- Drop totem-youtube-plugin-ui.patch, included upstream.
* Sun Jun 14 2009 vuntz@novell.com
- Update totem-plugins dependencies to cover all plugins:
  + remove python-gdata Requires, not needed anymore
  + change brasero Requires to Recommends
  + add python-beautifulsoup and python-httplib2 Recommends for BBC
    iPlayer plugin
  + add python-coherence Recommends for DLNA/UPnP Client plugin
  + add gromit Suggests for Gromit Annotation plugin
* Fri Jun 12 2009 vuntz@novell.com
- Add totem-youtube-plugin-ui.patch to fix crash because of invalid
  ui file.
* Mon May 25 2009 lnussel@suse.de
- lirc -> lirc-devel in BuildRequires
* Sun May 24 2009 vuntz@novell.com
- Add libgdata-devel BuildRequires.
* Thu May  7 2009 vuntz@novell.com
- Update to version 2.27.1:
  + Major changes:
  - Port GStreamer backend to playbin2
  - Remove xine-lib backend
  - New BBC iPlayer plugin
  - Port YouTube plugin to C, much faster
  - Use libunique instead of our home-cooked version
  + New features:
  - Add a D-Bus service plugin, to allow getting playback
    information from a running Totem
  - Add support for DVD navigation to the GStreamer backend
  + Misc bug fixes:
  - Remove relief from the playlist buttons
  - Set the default drag action to be copy, and only make
    the video widget a drag source when a video is loaded
- Add libunique-devel BuildRequires.
* Thu May  7 2009 vuntz@novell.com
- Merging a submission from lnussel@suse.de:
  + Small clean up to remove .la files
  + Split off nautilus plugin in nautilus-totem package to reduce
    dependencies of core package
  + Fix packaging of plugins to really be in the plugins package,
    and move some browser-plugin helper to the brower-plugin
    package.
- Add Supplements for totem/MozillaFirefox in the browser-plugin
  package.
- Do not package omf files twice.
* Sat Apr  4 2009 vuntz@novell.com
- Update to version 2.26.1:
  + General:
  - Use Ctrl+S instead of Shift+S for the screenshot capture
  - Parse session management options on the command-line
  - Reset the seekbar when a file is closed
  - Make the default drag action for the video widget be a copy
  - Reset the icon properly when deactivating the thumbnail
    plugin
  - Make sure all files are played when playing in shuffled mode,
    and repeat mode is switched off
  - Fix Rewind() and Stop() functions in the QuickTime compat plugin
  - Don't remove renamed files from the playlist
  + Subtitles download plugin:
  - Fix the OpenSubtitles plugin not loading
  - Sort languages names in alphabetical order
- Remove -fno-strict-aliasing from CFLAGS.
* Mon Mar 16 2009 vuntz@novell.com
- Update to version 2.26.0:
  + Make sure all the Python plugins are translated
  + Fix the language selection in the OpenSubtitles plugin
* Mon Mar  9 2009 vuntz@novell.com
- Add scrollkeeper BuildRequires because some translations were not
  ported to gnome-doc-utils.
* Sun Mar  8 2009 vuntz@novell.com
- Review changes.
* Wed Mar  4 2009 lmedinas@gmail.com
- Update to version 2.25.92:
  + Set PulseAudio application properties
  + Fix possible crasher in eggdesktopfile
  + Add support for MXF videos
  + Fix repeat not working in the browser plugin
  + Translation updates
* Mon Mar  2 2009 vuntz@novell.com
- Review changes.
* Tue Feb 17 2009 lmedinas@gmail.com
- Update to version 2.25.91:
  + Document internal API for plugin writers
  + Fix a few focus problems
  + Accept human-friendly inputs in the "Skip To" dialogue
  + Add a huge number of languages to the subtitle downloader plugin
  + Make looping smoother when only one file is being played in repeat
  + Make the gallery creation progress window work as expected
  + Many build fixes
  + Make Totem more robust when Python fails to initialise
- Add devel package for Totem developer documentation
* Thu Feb  5 2009 vuntz@novell.com
- Remove docbook_4 BuildRequires.
- Create a plugins package for the totem plugins.
- Rename the plugin package to browser-plugin.
- Recommends both plugins and browser-plugin from totem.
- Don't call autoreconf.
- Remove Requires on shared-mime-info for subpackages.
* Thu Feb  5 2009 lmedinas@gmail.com
- Update to version 2.25.90:
  + Add a UPNP/DLNA plugin
  + Add a plugin to allow creating galleries of screenshots
    for video files
  + Add a plugin to allow copying DVDs and VCDs through Brasero,
    as well as creating new DVDs from the playing video
  + Add support for Repeat and Shuffle through LIRC
  + Add support for a number of playlist types
  + Update audio and video files types supported by the properties
    window to not include playlists
  + Fix recent files not working when the playlist was empty
  + Avoid resetting colour balance sliders when set at the maximum
    or the minimum
  + Fix the screensaver not being disabled in some cases
  + Add number of build and UI fixes
  + Translation Updates
- Add Brasero to Requires to build Brasero plugin
* Thu Jan 22 2009 vuntz@novell.com
- Remove totem-browser-plugin-dir.patch: the environment variable
  that we set before configure works now.
* Tue Jan 13 2009 rodrigo@novell.com
- Depend on gnome-control-center-devel, not control-center2-devel
* Sat Dec 20 2008 mboman@suse.de
- Update to version 2.25.3:
  + Make the left-click seek directly to the destination
  + Hide colour balance sliders that aren't available
  + Make modifiers work as expected when drag'n'dropping files
  + Use "Movie Player" everywhere in the interface
  + Add an arrow to the sidebar button
  + Convert British English messages to American English
  + Show the fullscreen popups when seeking with the keyboard
  + Better behaviour when changing the type of playlist to be saved
  + Fix playlist problems when removing an file that was deleted
    from the filesystem
  + Add plugin to download text subtitles from OpenSubtitles.org
  + Allow selecting a text subtitle from the View menu, or by dropping
    the file onto the video widget
  + Add the subtitle and languages menus to the fullscreen popup
  + Remove the "basic" web browser plugin, we now use the same
    API as VideoLAN for our default plugin
  + Fix relative paths not resolving in some cases
  + Fix repeat=true only playing files twice
  + Add Jamendo plugin
  + Add support for streaming TV from MythTV
  + Fix YouTube movie playback following website changes
  + Make the local search and YouTube search sidebars look more alike
  + Add proper mute support for remote controls
  + Fix the metadata-updated signal to be useful
  + Remove libgnome dependency
  + Remove NVTV support
  + Use g_timeout_add_seconds() when possible
  + Require the rsndvdbin plugin for DVD playback
  + Add zoom support
  + Fix some files not giving us metadata with the video indexer
  + Fix the video window getting bigger than the screen
  + When streaming, the pause button stops
  + Add ability to create a gallery image using the video thumbnailer
- Reviewed work from lmedinas
* Sun Dec 14 2008 lmedinas@gmail.com
- Update to version 2.24.3:
  + Fixes for Youtube plugin
  + Allow clicking on the seekbar to get to the selected position
  + Fix some keys not being usable in the sidebar
* Wed Nov 26 2008 vuntz@novell.com
- Remove libnvtv-devel BuildRequires since nobody wants to maintain
  the nvtv packages.
* Thu Nov  6 2008 vuntz@novell.com
- Remove BuildRequires on libgalago-devel so we can remove galago
  from the repository. We lose the galago plugin, but it's not that
  useful anyway.
* Tue Nov  4 2008 ro@suse.de
- no nvtv on ia64 either, add to ifarch lists
* Fri Oct 10 2008 mboman@suse.de
- Update to version 2.24.2:
  + Make the YouTube plugin faster by fixing some locking problems
* Fri Oct  3 2008 mboman@suse.de
- Update to version 2.24.1:
  + Fix typo in the browser plugin documentation
  + Disable the code to remove deleted files from the playlist,
    it was broken
  + Fix a window parenting problem when using the GStreamer missing
    plugins code
* Tue Sep 23 2008 mboman@suse.de
- Update to version 2.24.0:
  + Add support for application/x-ms-wmp in the browser plugin
  + Fix recent-files not working
  + Never disable an invisible plugin
  + Allow the new GStreamer MPEG plugins to be used for DVD and DVB
* Mon Sep 15 2008 dmueller@suse.de
- adjust buildrequires
* Thu Sep  4 2008 mboman@novell.com
- Update to version 2.23.91:
  + Numerous UI and bug fixes
  + DVB playback:
  * Add support for a helper to setup DVB channels
  * Support multiple DVB adapters
  * Better DVB error messages
  + New features:
  * Allow '+' and '-' to go to the previous/next tracks
  * Make the LIRC plugin work out-of-the-box on a majority of remotes,
    and add support for the Stop key
  * Add a Python console plugin
  + Movie player:
  * Require a newer gmyth to support newer MythTV instances
  * UI fixes for the playlist and play buttons showing the wrong status
    on error
  * Fix restoring previous sessions
  * Don't resize the window in the middle of a stream, for example, when
    watching TV
  * Build fixes for Python and Vala plugin backends
  + Youtube plugin:
  * Fix webpage URLs getting added to the playlist, rather than movies
    themselves
  * Don't eat the CPU when searching for videos
  * Blacklist the ffmpeg FLV demuxer, and popup the plugin installation
    helper if no other demuxers are available
  + GStreamer backend:
  * Fix possible drifts in the colour balance
  * Fix the UI not updating for internet radio titles when streaming
  * Add support for ATSC (North-American DVB)
  * Update visualisations aspect ratio when the screen size changes
* Mon Sep  1 2008 wr@opensuse.org
- Totem doesn't need mozilla stuff to build the plugin
  (interface headers are in its own source tree) (bnc#420641)
* Mon Jun 23 2008 maw@suse.de
- Update to version 2.23.4:
  + The backend is built as a shared library instead of statically
    in the frontends, so that they may easily be swapped out
  + Automatically remove files from the playlist when they've been
    removed from the filesystem
  + Replace gnome-vfs with gio
  + Add audio/x-speex as a supported mime-type
  + Update Vala sample plugin and bindings to use new features
  + Movie Player:
  * Add an icon to "Clear playlist"
  * Fix the bug report script
  * Fix crasher when trying to load (unsupported) audio CDs
  + Plugins (general):
  * Remove the need to configure the MythTV plugin; use UPNP
    instead
  * Use ~/.local/share/totem/plugins for user-installed
    plugins
  + Web browser plugin:
  * Remove mozilla specific requirements
  * Show stream titles in fullscreen
  * Add double-click -> fullscreen
  * Hide controls by default in the Cone (VLC) plugin
  * Implement Playlist::isplaying for Cone
  + YouTube Plugin:
  * Make the plugin faster, by downloading less data
  * Don't crash when the server returns HTTP errors
  * Check for required GStreamer plugins in the YouTube plugin
  * Add ability to launch YouTube videos in a web browser from
    the YouTube plugin
  * Add a progress bar
  * Add support for high-res videos
  + GStreamer backend:
  * Fix a possible crash when forcing use of ximagesink (as is
    the case for small videos on trailers.apple
  + xine-lib backend:
  * Allow loading remote subtitle files using gvfs' fuse
  * Fix potential crasher when copying MRLs from the engine
- Drop an obsolete patch: totem-1.2.1-desktop.sh.patch.
- Add totem-browser-plugin-dir.patch.
* Sat May  3 2008 vuntz@suse.de
- Add python-gdata requires, so that the youtube plugin
  automatically works (well, if the right gstreamer plugins are
  installed too...).
* Mon Mar 17 2008 vuntz@suse.de
- Kill totem-dbus060.patch, it's not needed since 2006 at least
  because totem defines DBUS_NAME_FLAG_PROHIBIT_REPLACEMENT if
  required.
- Tag totem-1.2.1-desktop.sh.patch. It will be fixed in next
  version of totem.
* Thu Mar 13 2008 vuntz@suse.de
- Update to version 2.22.0:
  + Update GTK+ requirement for the accessibility support
  + Updated translations.
- Changes from version 2.21.96:
  + Add missing accessibility properties to the interface files
  + Fix some warnings in the help files
  + xine-lib backend:
  * Fix crash when using multi-head
  + GStreamer backend:
  * When resizing a visualisation, resize to the native
    resolution, not the minimum size
  * Add DVB-C (digital cable TV) support
* Wed Mar  5 2008 maw@suse.de
- Update to version 2.21.95:
  + Build fixes
  + Support audio/midi
  + Only stay on top when video is playing back, not during
    visualisations
  + Fix logic in the channels.conf parsing for DVB in the
    gstreamer backend
- Provide and obsolete totem-devel.
* Wed Feb 20 2008 maw@suse.de
- Update to version 2.21.93:
  + New plugins: MythTV, YouTube, Cone, video search
  + Add the ability to drop files in specific places in the
    playlist
  + Remove support for audio CDs
  + Subtitle handling changes
  + Various bugfixes
- Update build requirements
- Drop the -devel subpackage.
* Wed Oct 17 2007 sbrabec@suse.cz
- Fixed plugin directory and package splitting (#334081).
- Build bemused, galago, media-player-keys and python plugins.
- Updated BuildRequires.
* Tue Sep 18 2007 maw@suse.de
- Update to version 2.20.0:
  + Better error when there are no DVD plugins available
  + Fix dropping URLs from Firefox/Mozilla-based browsers
  + Fix the media players key plugin not starting automatically
  + Stop the screensaver when we're playing, not only in fullscreen
  + Fix the visuals plugins list being always empty
  + Don't allow seeking when there's no files loaded
  + Don't ask the user twice whether to disable visualisations when
    running remotely
  + Disable the Eject menu item, as it's not working properly
  + Don't rebuild the drives list for each click on the Movie menu
  + Add audio/off and audio/x-sbc as supported
  + Fix some problems when the position (0->1.0) doesn't match
    time elapsed/duration (xine-lib)
  + Start playback when running "totem dvb:" (xine-lib)
  + Fix a crash when trying to use "totem dvb:" (GStreamer)
  + Browser plugin:
  * Stop the play button glowing when we click play
  * Don't call out to the viewer if it's not started yet
  * Stop the screensaver when we're playing
  * Show an icon in the about dialogue
  + Playlist parser:
  * Add starttime and endtime support for RAM files
  * When getting a cdda:/// URL, use the canonical device,
    not the link to the device
  * Push the duration attribute for PLS files
  * Don't crash or eject the CD/DVD when trying to play a disc
    that's not mounted.
* Fri Aug 31 2007 maw@suse.de
- Update to version 2.19.90:
  * Make the default window size bigger on first startup
  * Remove most of the flicker from the waiting cursor on startup
  * Fix hang on startup with some versions of GCC
  * Fix crashes when opening files with non-UTF-8 filenames
  * Fix the fullscreen seekbar not working
  * Browser plugin:
  - Support the .Mac galleries
  - Support replaying videos when they're in the browser cache
  - Make the glow button behave better when the mouse pointer is
    inside it, glow when a new file is ready to play and requires
    the user to click play
  - Support the video/x-m4v and application/asx mime-types
  - Save the volume from video to video
  - Naively skip unplayable items in playlists
  - Support ASX playlists with starttime
  - Fix some really small videos not showing up in the browser
  * Playlist parser:
  - Add PLA playlist write support
  - Only push UTF-8 strings to the applications
  - Fix parsing of some complicated relative URLs
  - Fix parsing of M3U playlists when the files have spaces in
    their name
  - Push the starttime and duration properties to applications
    from ASX playlists
  * xine-lib backend:
  - Fix the seekbar not moving when playing an unseekable source
    (such as browser streams in the browser plugin)
* Tue Aug  7 2007 maw@suse.de
- Split off a -lang subpackage
- s#%%run_ldconfig#/sbin/ldconfig# in %%post and %%postun.
* Thu Aug  2 2007 maw@suse.de
- Update to version 2.19.6:
  * Features:
- Detect DVD rips even if the VIDEO_TS directory is passed, and not the
  top-level directory
- Add support for the Back, Forward, Open, Open URL, Eject, Save,
  Zoom In, Zoom out multimedia keys
- Add support for Python and Vala plugins
- Move the "Open Location" dialogue to a plugin
- Also show comments in the properties tab and sidebar
- Make the play button glow when autostart is off, to avoid not seeing anything
- Use the GTK+ volume widget
- Add a Bemused server plugin
- Add FLV and NSV support to the browser plugin
- Add PLA playlist read support
- Add fullscreen support to the browser plugin
  Bug fixes:
- Fix parsing of some playlists when the base ended with a '/'
- Don't crash when searching in plugins list
- Fix the properties page missing some symbols
- Make recent streams parsing faster in the "Open Location" dialogue
- Fix the second file in a playlist not updating the seekbar
- Use double-buffering in logo mode, or when showing the logo in audio-only mode
- Draw a nice black background on the video widget's place
- Fix parsing of ASX playlists when an entryref doesn't have a parent
- Use a combobox for the sidebar drop-down
- Use Glib's function for xdg-user-dirs support
- Use GtkBuilder in loads of place
- Fix visual effects showing up in the middle of a video in the browser plugin
  (xine-lib)
- Use %%fdupes.
* Mon Jul  9 2007 mauro@suse.de
- Update to version 2.19.4
- Bugfixes for #438934, #442371, #442673, #440911, #428291,
  [#439160], #428293, #401079, #435523.
* Wed May  9 2007 pgajdos@suse.cz
- removed gnome-icon-theme from Requires and BuildRequires
  [#247450]
* Fri Apr 27 2007 sbrabec@suse.cz
- Do not call meinproc (#227624).
* Thu Apr 12 2007 maw@suse.de
- Update to version 2.18.1
- * Add xdg-user-dirs support, show Movies and Music directories
  in the file choosers
  * Avoid crashes when we can't figure out a file's display name
  and we're adding it to the recent files list
  * Make adding multiple files to a running Totem work again
  * Misc build, bug and memory leak fixes
  * GStreamer:
- Don't ask over and over when the user cancels a helper for a
  missing plugin
- Call the missing plugins helper when there's no video available
  and a subtitle was used
- Make the seek bar behaves properly when no soundcards are used
  * Browser plugin:
- Remove rejection of streams based on mime-type, should allow
  playback of many more broken servers
- Make the wheel act properly on the volume button
* Mon Apr  9 2007 maw@suse.de
- Update to version 2.18.0
- fixes for bugzilla.gnome.org #415389, #405883, #415326, #414961,
  [#386558], #413065, #411408, #412560, #404304, #379742, #355881,
  [#402920], #407679, #374470, #405880, #405850, #406806, and
  [#405758]
- Cleaned up .desktop file
* Wed Apr  4 2007 sbrabec@suse.cz
- Do not require no more existing gstreamer010-plugins-base-oil.
* Fri Mar  9 2007 maw@suse.de
- Update to version 2.17.91
  * Fix crasher when getting the listed of subtitles/languages
  * Handle the icyx:// protocol
  * Add video/x-theora+ogg, application/ram, video/x-matroska,
    audio/x-matroska and audio/x-wavpack to the supported mime-types
  * Solaris compilation fixes
  * Fix vanity compilation
  * Fix using the playlist parser from Python
  * Have "Audio files" and "Video files" filters in the Open dialogues
  * Browser plugin:
  - Add stubs of Javascript support for the GMP (Windows Media compatible)
    browser plugin
  * GStreamer backend:
  - More robust code to check for stream metadata
  - Fix title streaming in internet radios
  * xine-lib backend:
  - Fix blue-ish pictures created by the thumbnailer
  * Fix build with older GCCs, older Mozillas, "-j2", and Solaris
  * Add support for the new "Media Player keys" infrastructure in
    GNOME 2.18
  * Append "#X" number to duplicate languages in the menu entries
  * Add "TrueAudio" as a supported file type
  * Add an uninstalled pkgconfig file for the playlist parser
  * Fix launching Totem remotely (broken by GOption work earlier in 2.17.x)
  * Make GTK+-only version compile again
  * Fix disabling the browser plugin using configure
  * Playlist parser:
  - Only export public symbols from the library
  - Avoid crashing when an MP3 that we can't get info about is being parsed
  * Browser plugin:
  - Add stubs of Javascript support for the NarrowSpace (Quicktime-
    compatible) and Complex (Real/Helix-compatible) plugins
  - Only set the "hand" cursor when we're ready to be clicked
  - Only stop using video acceleration when the video size is given
  * Thumbnailer:
  - Avoid crashes with newer version of GLib
  - Add a --verbose output
  * GStreamer:
  - Make mouse events work properly while playing
  - When reaching the end of a file while seeking, go to the next
    item in the list, instead of getting closer and closer to the end
  - Show an error when we're missing the video decoder for a file
  - Avoid reentrancy errors by handling errors asynchronously (avoids
    bad state when clicking too fast)
- many more fixes between 2.17.0 and 2.17.5
- Fix totem-dbus060.patch to apply to a different file
* Fri Mar  9 2007 sbrabec@suse.cz
- Removed obsolete hicolor icon symlink (#248676).
* Wed Feb  7 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552).
* Thu Jan 18 2007 sbrabec@suse.cz
- Plugin packaging cleanup (#236062). Patch from Andreas Hanke.
* Tue Dec 19 2006 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Fri Dec  8 2006 sbrabec@suse.cz
- Do not require xulrunner by runtime (#226945).
* Thu Nov 30 2006 sbrabec@suse.cz
- Fixed xulrunner dependencies for older products.
* Tue Nov 21 2006 sbrabec@suse.cz
- Do not explicitly require mDNSResponder-lib blocking avahi compat
  package.
* Mon Nov 13 2006 sbrabec@suse.cz
- Use exact xulrunner version 181 (#218792, #216100).
* Fri Nov  3 2006 abockover@suse.de
- Disable complex/Helix-emulation plugin (BNC #209337)
* Fri Oct 13 2006 aj@suse.de
- Add gnome-doc-utils-devel to BuildRequires.
* Mon Oct  2 2006 jhargadon@suse.de
- update to version 2.17.0
- Updated documentation
- Use new GtkRecentManager as the rest of GNOME 2.16
- Handle the Apple Remote's menu button when playing back DVDs
- Add audio sample rate and audio channels in the properties
- Set volume up/down sensitivity properly when reaching a boundary
- Use the builtin overwrite confirmation when saving playlists
- Change the title when changing songs on Shoutcasts streams
- Add support for multiple selections in the playlist popup menu
* Sat Sep 30 2006 aj@suse.de
- Disable scrollkeeper.
- Compile C++ files with RPM_OPT_FLAGS.
* Tue Sep 26 2006 jhargadon@suse.de
- fixed the location of the plugin files to be in the correct
  location as specified in bug #208187
* Thu Sep 14 2006 jhargadon@suse.de
- update to version 2.16.0
- Add keyboard support for the DVD keys: Up, Down, Left, Right
- Add support for audio/AMR, audio/AMR-WB and Musepack
- Remove old GStreamer 0.8 hacks
- Avoid repeat being turned on when it shouldn't in the web browser plugin
* Wed Sep 13 2006 ro@suse.de
- own mozilla plugin dirs to fix build
* Tue Sep 12 2006 ro@suse.de
- completely disable plugin to workaround rpm crash
* Wed Aug 30 2006 jhargadon@suse.de
- update to version 1.5.92
- Fix a crash when HAL isn't available
- Fix compilation with older versions of HAL, without HAL, and with the
  Browser plugin disabled
- Save and restore the sidebar width
- Set and use the connection speed preference
- Numerous Browser Plugin enhancements:
  - Playlist support
  - Split the plugin in 4 different plugins, to allow
    name-based detection to work, and different Javascript interfaces
    to be used (Real Player/Helix, Windows Media Player and Quicktime
    compatible, and basic Totem)
  - Handle repeat and autostart parameters
  - Make sure the plugin is available for all Mozilla-based browsers
  - Make scrolling on the volume widget work as it should
- New icon
- Use HAL to determine the disc type
- Save and restore which sidebar was showing, and whether Totem was
  maximised
- Fix the window title not changing when playing files with broken names
- Fix Ctrl+Q not working in fullscreen
- More logo mode fixes
- Fix aspect ratio of visuals
* Tue Aug  8 2006 gekker@suse.de
- Update to version 1.5.90
- Re-enable vanity webcam as it works with this version (#173694)
- Remove upstreamed patches
  * Add a default filename to the save playlist dialogue
  * Add supprot for more DVD related remote buttons
  * Move the properties dialogue to the sidebar
  * Fix build with newer versions of D-Bus
  * Avoid linking directly against the Mozilla libraries, should allow
  build-time and run-time engines to be different (build against Mozilla,
  run in Firefox)
  * Make the "Seek To" dialogue work correctly when using the keyboard
  * Try harder to extract audio/subtitles languages from files (GStreamer)
  * Fix crashes
  * Text subtitle encoding is now selectable
  * Numerous Browser Plugin enhancements:
  - Try to cache files while playing them
  - Add support for cache=true hint
  - Fix getting the true path for relative paths
  - Add support for audio-only playback
  - Add a way to copy the URL from the right-click menu
  - Add "Open in Movie Player" in the right-click menu
  * Make showing/hiding the sidebar not resize the video or the window
  * Add AC3 and Monkey's audio to the known filetypes
  * Fix memory leaks
  * Fix the "Skip to" dialogue not working when paused (GStreamer)
  * Make Space Play/Pause when the video widget has the focus
  * Fix DVD playback when started from gnome-volume-manager
  * Use HAL to detect presence of discs in the drives
  * Add Impulse Tracker and MOD files to the list of supported types
  * Add audio/vnd.rn-realaudio as a supported playlist format
  * Add XSPF playlists read and write support
  * Allow users to choose the type of playlist to write when saving
  * Fix the GTK+-only version not displaying some menu items
  * Add basic support for the Quicktime Metalink playlists
  * Make menu shortcuts unaccessible in fullscreen
  * Make the preferences window appear on top of the main window at all times,
  and hide it straight away when exiting
* Tue Aug  1 2006 schwab@suse.de
- Remove newlines from substituted variable.
* Tue Jul 18 2006 aj@suse.de
- Use PACKAGE_VERSION to fix build.
* Tue May  9 2006 jpr@suse.de
- Disable vanity in build (#173694)
* Sat Apr  8 2006 aj@suse.de
- Add BuildRequire for gstreamer010-plugins-base-oil.
* Mon Apr  3 2006 jpr@suse.de
- Update to totem 1.4.0 to get gstreamer 0.10 support
- Removed upstreamed patch
* Wed Mar 29 2006 sbrabec@suse.cz
- Typo fix in cs.po (GNOME#336012).
* Fri Mar 17 2006 federico@novell.com
- Added totem-init-backend-later.diff so that the Nautilus extension will not
  do unnecessary work at startup.
* Tue Feb 28 2006 sbrabec@suse.cz
- Use kdelibs3-doc in BuildRequires for meinproc (#153635#c14).
* Mon Feb 27 2006 gekker@suse.de
- Add %%run_ldconfig to %%post (#153409)
* Fri Feb 17 2006 gekker@suse.de
- update .desktop files for UI team
* Tue Feb 14 2006 ke@suse.de
- totem-1.2.1-desktop.sh.patch: After the final Mime type entry close
  line with newline.
* Tue Feb  7 2006 ro@suse.de
- no nvtv for ppc/ppc64/s390/s390x
* Thu Feb  2 2006 sbrabec@suse.cz
- Reduced BuildRequires.
* Thu Feb  2 2006 sbrabec@suse.cz
- Explicitly require iso-codes (#147467).
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 18 2006 sbrabec@suse.cz
- Updated to version 1.2.1.
* Wed Dec 21 2005 ro@suse.de
- fix build with current dbus
* Thu Oct 13 2005 ro@suse.de
- fix build with xulrunner
* Thu Sep 15 2005 sbrabec@suse.cz
- Disable plugin for older products - it needs recent DBUS.
* Wed Sep 14 2005 sbrabec@suse.cz
- Fixed requirements.
- Enabled vanity and browser plugin.
- Split devel and plugin subpackages.
- Description and license updated.
* Mon Sep 12 2005 sbrabec@suse.cz
- Do not try to link with nvtv library in 9.3 and older.
* Mon Sep  5 2005 sbrabec@suse.cz
- Updated to version 1.2.0.
* Wed Aug 24 2005 gekker@suse.de
- Update to version 1.1.5
* Fri Jul 22 2005 gekker@suse.de
- Update to version 1.1.3
* Wed Jun 22 2005 gekker@suse.de
- Update to version 1.1.2
* Fri Mar 18 2005 gekker@suse.de
- Fix typo in Requires
* Thu Mar 17 2005 gekker@suse.de
- Add gstreamer-plugins-extra to nfb and Requires (72273).
* Wed Mar 16 2005 sbrabec@suse.cz
- Removed SWF (#72417) and Real (#72985) MIME type association.
* Wed Mar 16 2005 ke@suse.de
- Fix .desktop file [# 67352].
* Thu Mar 10 2005 gekker@suse.de
- Update to version 1.0 (GNOME 2.10).
* Wed Jan 26 2005 gekker@suse.de
- Update to version 0.101
* Tue Nov  2 2004 mmj@suse.de
- Locale rename no to nb
- Don't remove buildroot when installing
* Mon Aug 30 2004 shprasad@suse.de
- Fixes bug #63393.
  Removed the Download button.
* Fri Aug 27 2004 clahey@suse.de
- Cache totem help and show totem in khelpcenter.
* Fri Jul 30 2004 shprasad@suse.de
- Fixes bug #60102 (Fix given by svasista@novell.com)
  Correctly displays the recent files opened.
* Tue May 11 2004 sbrabec@suse.cz
- Fixed gconftool-2 prerequirements.
* Thu Mar 18 2004 adrian@suse.de
- fix double menu entries
* Wed Mar 10 2004 sbrabec@suse.cz
- Fixed gconf schemas installation (#33114).
* Thu Feb 19 2004 sbrabec@suse.cz
- Updated to version 0.99.9.
* Tue Feb 17 2004 adrian@suse.de
- fix Categories
* Sun Jan 11 2004 adrian@suse.de
- fix build as user
* Mon Oct 27 2003 sbrabec@suse.cz
- Updated to verion 0.99.7.
* Fri Oct 10 2003 sbrabec@suse.cz
- Updated to version 0.99.5.
* Sun Sep 14 2003 adrian@suse.de
- define Categories also for vanity
* Fri Sep  5 2003 adrian@suse.de
- mark it as Video player
* Fri Aug 15 2003 adrian@suse.de
- add Categories
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Tue Jul  8 2003 sbrabec@suse.cz
- Initial SuSE version.
